from setuptools import setup

setup(name='pickrr',
      version='0.1',
      description='Pickrr order placing, order cancellation and order tracking api',
      url='http://github.com/harishbisht/pickrr',
      author='Harish Bisht',
      author_email='harish@pickrr.com',
      license='MIT',
      packages=['pickrr'],
      zip_safe=False)